@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020, Dr Alex Meakins, Raysect Project
+# Copyright (c) 2014-2021, Dr Alex Meakins, Raysect Project
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -481,6 +481,12 @@ class TestVector3D(unittest.TestCase):
         self.assertAlmostEqual(r.length, 1, msg='Spherical lerp operation failed.')
         self.assertAlmostEqual(theta, 90, msg='Spherical lerp operation failed.')
 
+        # test parallel vectors
+        r = a.slerp(a, 0.5)
+        self.assertAlmostEqual(r.x, 1.0, msg='Spherical lerp operation failed.')
+        self.assertAlmostEqual(r.y, 0, msg='Spherical lerp operation failed.')
+        self.assertAlmostEqual(r.z, 0, msg='Spherical lerp operation failed.')
+
 
 if __name__ == "__main__":
     unittest.main()
